@@ -37,15 +37,14 @@ Supported Knot versions: >= 2.1, < 3
 
 Configured in [service:agent:knot2]
 """
-import six
 
 from oslo_concurrency import lockutils
 from oslo_concurrency.processutils import ProcessExecutionError
 from oslo_config import cfg
 from oslo_log import log as logging
 
-from designate import exceptions
 from designate.backend.agent_backend import base
+from designate import exceptions
 from designate.utils import execute
 
 CFG_GROUP_NAME = 'backend:agent:knot2'
@@ -160,7 +159,7 @@ class Knot2Backend(base.AgentBackend):
         try:
             serial = out.split('|')[1].split()[1]
             return int(serial)
-        except Exception as e:
+        except Exception:
             LOG.error("Unable to parse knotc output: %r", out)
             raise exceptions.Backend("Unexpected knotc zone-status output")
 
@@ -172,7 +171,7 @@ class Knot2Backend(base.AgentBackend):
         :type zone: raw pythondns Zone
         """
         zone_name = zone.origin.to_text(omit_final_dot=True)
-        if six.PY3 and isinstance(zone_name, bytes):
+        if isinstance(zone_name, bytes):
             zone_name = zone_name.decode('utf-8')
         LOG.debug("Creating %s", zone_name)
         # The zone might be already in place due to a race condition between
@@ -192,7 +191,7 @@ class Knot2Backend(base.AgentBackend):
         :type zone: raw pythondns Zone
         """
         zone_name = zone.origin.to_text(omit_final_dot=True)
-        if six.PY3 and isinstance(zone_name, bytes):
+        if isinstance(zone_name, bytes):
             zone_name = zone_name.decode('utf-8')
         LOG.debug("Triggering AXFR from MiniDNS to Knot for %s", zone_name)
         self._start_minidns_to_knot_axfr(zone_name)
